@@ -1456,12 +1456,17 @@ CCSStringList
 ccsGetSortedPluginStringList (CCSContext * context)
 {
     CCSPluginList ap = ccsGetActivePluginList (context);
-    CCSPluginList list = ap;
+    CCSPluginList list;
     CCSPlugin *p = NULL;
-    CCSStringList rv = NULL;
+    CCSStringList rv = ccsStringListAppend (NULL, strdup ("core"));
     PluginSortHelper *ph = NULL;
 
+    p = findPluginInList (ap, "core");
+    if (p)
+	ap = ccsPluginListRemove (ap, p, FALSE);
+
     int len = ccsPluginListLength (ap);
+    
     int i, j;
     /* TODO: conflict handling */
 
@@ -1469,7 +1474,7 @@ ccsGetSortedPluginStringList (CCSContext * context)
     if (!plugins)
 	return NULL;
 
-    for (i = 0; i < len; i++, list = list->next)
+    for (i = 0, list = ap; i < len; i++, list = list->next)
     {
 	plugins[i].plugin = list->data;
 	plugins[i].after = NULL;
@@ -1547,6 +1552,11 @@ ccsGetSortedPluginStringList (CCSContext * context)
 	    if (plugins[i].after)
 		continue;
 
+	    /* This is a special case to ensure that bench is the last plugin */
+	    if (len - removed > 1 &&
+		strcmp (plugins[i].plugin->name, "bench") == 0)
+		continue;
+
 	    found = TRUE;
 	    removed++;
 	    p = plugins[i].plugin;
